@@ -18,6 +18,8 @@
 #ifndef GPARTED_DIALOG_BASE_PARTITION_H
 #define GPARTED_DIALOG_BASE_PARTITION_H
 
+
+#include "Device.h"
 #include "Frame_Resizer_Extended.h"
 #include "FileSystem.h"
 #include "OptionComboBox.h"
@@ -37,7 +39,7 @@ class Dialog_Base_Partition : public Gtk::Dialog
 {
 public:
 	
-	Dialog_Base_Partition( ) ;
+	Dialog_Base_Partition(const Device& device);
 	~Dialog_Base_Partition( ) ;
 
 	void Set_Resizer( bool extended ) ;
@@ -57,6 +59,9 @@ protected:
 	};
 
 	void prepare_new_partition();
+	static void snap_to_alignment(const Device& device, Partition& partition);
+	static void snap_to_cylinder(const Device& device, Partition& partition);
+	static void snap_to_mebibyte(const Device& device, Partition& partition);
 
 	void Set_Confirm_Button( CONFIRMBUTTON button_type ) ;
 	void Set_MinMax_Text( Sector min, Sector max ) ;
@@ -90,6 +95,7 @@ protected:
 
 	bool fixed_start, GRIP ;
 	double before_value ;
+	const Device& m_device;
 	FS fs ;
 	FS_Limits fs_limits;  // Working copy of file system min/max size limits
 
