@@ -33,28 +33,40 @@
 namespace GParted
 {
 
+struct MountEntry
+{
+	bool                       readonly;     // Is the file system mounted read-only?
+	std::vector<Glib::ustring> mountpoints;  // File system mounted on ...
+
+	MountEntry() : readonly( false )  {};
+};
+
 class Mount_Info
 {
 public:
-	typedef std::map<BlockSpecial, std::vector<Glib::ustring> > MountMapping;
+	typedef std::map<BlockSpecial, MountEntry> MountMapping;
 
 	static void load_cache();
 	static bool is_dev_mounted( const Glib::ustring & path );
 	static bool is_dev_mounted( const BlockSpecial & bs );
+	static bool is_dev_mounted_readonly( const Glib::ustring & path );
+	static bool is_dev_mounted_readonly( const BlockSpecial & bs );
 	static std::vector<Glib::ustring> get_all_mountpoints();
 	static const std::vector<Glib::ustring> & get_mounted_mountpoints( const Glib::ustring & path );
 	static const std::vector<Glib::ustring> & get_fstab_mountpoints( const Glib::ustring & path );
 
 private:
 	static void read_mountpoints_from_file( const Glib::ustring & filename, MountMapping & map );
-	static void add_node_and_mountpoint( MountMapping & map,
-	                                     Glib::ustring & node,
-	                                     Glib::ustring & mountpoint );
+	static void add_mountpoint_entry( MountMapping & map,
+	                                  Glib::ustring & node,
+	                                  Glib::ustring & mountpoint,
+	                                  bool readonly );
+	static bool parse_readonly_flag( const Glib::ustring & str );
 	static void read_mountpoints_from_file_swaps( const Glib::ustring & filename,
 	                                              MountMapping & map );
 	static bool have_rootfs_dev( MountMapping & map );
 	static void read_mountpoints_from_mount_command( MountMapping & map );
-	static const std::vector<Glib::ustring> & find( const MountMapping & map, const Glib::ustring & path );
+	static const MountEntry & find( const MountMapping & map, const Glib::ustring & path );
 };
 
 } //GParted
