@@ -18,8 +18,10 @@
 #ifndef GPARTED_OPERATION_H
 #define GPARTED_OPERATION_H
 
-#include "../include/Device.h"
-#include "../include/OperationDetail.h"
+#include "Device.h"
+#include "OperationDetail.h"
+#include "Partition.h"
+#include "PartitionVector.h"
 
 namespace GParted
 {
@@ -42,16 +44,19 @@ class Operation
 public:
 	Operation() ;
 	virtual ~Operation() {}
-	
-	virtual void apply_to_visual( std::vector<Partition> & partitions ) = 0 ;
+
+	Partition & get_partition_original();
+	const Partition & get_partition_original() const;
+	virtual Partition & get_partition_new();
+	const virtual Partition & get_partition_new() const;
+
+	virtual void apply_to_visual( PartitionVector & partitions ) = 0;
 	virtual void create_description() = 0 ;
 	virtual bool merge_operations( const Operation & candidate ) = 0;
 
 	//public variables
 	Device device ;
 	OperationType type ;
-	Partition partition_original ; 
-	Partition partition_new ;
 
 	Glib::RefPtr<Gdk::Pixbuf> icon ;
 	Glib::ustring description ;
@@ -59,12 +64,27 @@ public:
 	OperationDetail operation_detail ;
 
 protected:
-	int find_index_original( const std::vector<Partition> & partitions ) ;
-	int find_index_new( const std::vector<Partition> & partitions );
-	int find_index_extended( const std::vector<Partition> & partitions ) ;
-	void insert_unallocated( std::vector<Partition> & partitions, Sector start, Sector end, Byte_Value sector_size, bool inside_extended );
-	void substitute_new( std::vector<Partition> & partitions );
-	void insert_new( std::vector<Partition> & partitions );
+	int find_index_original( const PartitionVector & partitions );
+	int find_index_new( const PartitionVector & partitions );
+	void insert_unallocated( PartitionVector & partitions,
+	                         Sector start, Sector end, Byte_Value sector_size, bool inside_extended );
+	void substitute_new( PartitionVector & partitions );
+	void insert_new( PartitionVector & partitions );
+
+	Partition * partition_original;
+	Partition * partition_new;
+
+private:
+	// Disable compiler generated copy constructor and copy assignment operator by
+	// providing private declarations and no definition.  Code which tries to copy
+	// construct or copy assign this class will fail to compile.
+	// References:
+	// *   Disable copy constructor
+	//     http://stackoverflow.com/questions/6077143/disable-copy-constructor
+	// *   Disable compiler-generated copy-assignment operator [duplicate]
+	//     http://stackoverflow.com/questions/7823845/disable-compiler-generated-copy-assignment-operator
+	Operation( const Operation & src );              // Not implemented copy constructor
+	Operation & operator=( const Operation & rhs );  // Not implemented copy assignment operator
 };
 
 } //GParted
