@@ -17,7 +17,9 @@
 #ifndef GPARTED_OPERATIONCHANGEUUID_H
 #define GPARTED_OPERATIONCHANGEUUID_H
 
-#include "../include/Operation.h"
+#include "Operation.h"
+#include "Partition.h"
+#include "PartitionVector.h"
 
 namespace GParted
 {
@@ -29,10 +31,14 @@ public:
 	                   , const Partition & partition_orig
 	                   , const Partition & partition_new
 	                   ) ;
+	virtual ~OperationChangeUUID();
 
-void apply_to_visual( std::vector<Partition> & partitions ) ;
+	void apply_to_visual( PartitionVector & partitions );
 
 private:
+	OperationChangeUUID( const OperationChangeUUID & src );              // Not implemented copy constructor
+	OperationChangeUUID & operator=( const OperationChangeUUID & rhs );  // Not implemented copy assignment operator
+
 	void create_description() ;
 	bool merge_operations( const Operation & candidate );
 } ;
