@@ -17,7 +17,9 @@
 #ifndef GPARTED_OPERATIONLABELFILESYSTEM_H
 #define GPARTED_OPERATIONLABELFILESYSTEM_H
 
-#include "../include/Operation.h"
+#include "Operation.h"
+#include "Partition.h"
+#include "PartitionVector.h"
 
 namespace GParted
 {
@@ -28,10 +30,14 @@ public:
 	OperationLabelFileSystem( const Device & device,
 	                          const Partition & partition_orig,
 	                          const Partition & partition_new );
+	virtual ~OperationLabelFileSystem();
 
-	void apply_to_visual( std::vector<Partition> & partitions );
+	void apply_to_visual( PartitionVector & partitions );
 
 private:
+	OperationLabelFileSystem( const OperationLabelFileSystem & src );              // Not implemented copy constructor
+	OperationLabelFileSystem & operator=( const OperationLabelFileSystem & rhs );  // Not implemented copy assignment operator
+
 	void create_description() ;
 	bool merge_operations( const Operation & candidate );
 } ;
