@@ -141,11 +141,12 @@ public:
 	static Glib::RefPtr<Gdk::Pixbuf> get_color_as_pixbuf(FSType fstype, int width, int height);
 	static int get_max_partition_name_length( Glib::ustring & tabletype );
 	static int get_filesystem_label_maxlength(FSType fstype);
-	static Glib::ustring get_filesystem_string(FSType fstype);
+	static const Glib::ustring get_filesystem_string(FSType fstype);
 	static const Glib::ustring get_encrypted_string();
 	static const Glib::ustring get_filesystem_string( bool encrypted, FSType fstype );
 	static const Glib::ustring get_filesystem_kernel_name( FSType fstype );
-	static Glib::ustring get_filesystem_software(FSType fstype);
+	static const Glib::ustring get_filesystem_software(FSType fstype);
+	static const Glib::ustring generate_encryption_mapping_name(const Glib::ustring& path);
 	static bool kernel_supports_fs( const Glib::ustring & fs ) ;
 	static bool kernel_version_at_least( int major_ver, int minor_ver, int patch_ver ) ;
 	static Glib::ustring format_size( Sector sectors, Byte_Value sector_size ) ;
