@@ -19,9 +19,9 @@
 #ifndef GPARTED_BTRFS_H
 #define GPARTED_BTRFS_H
 
-#include "../include/FileSystem.h"
-#include "../include/BlockSpecial.h"
-#include "../include/Partition.h"
+#include "FileSystem.h"
+#include "BlockSpecial.h"
+#include "Partition.h"
 
 namespace GParted
 {
@@ -43,7 +43,7 @@ public:
 	void read_uuid( Partition & partition ) ;
 	bool write_uuid( const Partition & partition, OperationDetail & operationdetail );
 	bool create( const Partition & new_partition, OperationDetail & operationdetail ) ;
-	bool resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition = false ) ;
+	bool resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition );
 	bool check_repair( const Partition & partition, OperationDetail & operationdetail ) ;
 
 	static void clear_cache() ;
