@@ -33,6 +33,12 @@ public:
 	udf() : old_mkudffs( false ) {};
 
 	FS get_filesystem_support();
+	FS_Limits get_filesystem_limits( const Partition & partition ) const;
+	void set_used_sectors( Partition & partition );
+	void read_label( Partition & partition );
+	bool write_label( const Partition & partition, OperationDetail & operationdetail );
+	void read_uuid( Partition & partition );
+	bool write_uuid( const Partition & partition, OperationDetail & operationdetail );
 	bool create( const Partition & new_partition, OperationDetail & operationdetail );
 
 private:
