@@ -33,7 +33,7 @@ Dialog_Partition_New::Dialog_Partition_New( const Device & device,
                                             bool any_extended,
                                             unsigned short new_count,
                                             const std::vector<FS> & FILESYSTEMS )
- : Dialog_Base_Partition(device)
+ : Dialog_Base_Partition(device), default_fs(-1)
 {
 	/*TO TRANSLATORS: dialogtitle */
 	this ->set_title( _("Create new Partition") ) ;
@@ -177,10 +177,12 @@ void Dialog_Partition_New::set_data( const Device & device,
 	TOTAL_MB = Utils::round( Utils::sector_to_unit( selected_partition.get_sector_length(),
 	                                                selected_partition.sector_size, UNIT_MIB ) );
 	MB_PER_PIXEL = TOTAL_MB / 500.00 ;
-	
-	//set first enabled file system
-	combo_filesystem.set_active(first_creatable_fs);
-	combobox_changed(false);
+
+	// Set default creatable file system.
+	// (As the change signal for combo_filesystem has already been connected,
+	// combobox_changed(false) is automatically called by setting the active
+	// selection.  This is needed to initialise everything correctly).
+	combo_filesystem.set_active(default_fs);
 
 	//set spinbuttons initial values
 	spinbutton_after .set_value( 0 ) ;
@@ -325,12 +327,12 @@ const Partition & Dialog_Partition_New::Get_New_Partition()
 }
 
 
-void Dialog_Partition_New::combobox_changed(bool type)
+void Dialog_Partition_New::combobox_changed(bool combo_type_changed)
 {
 	g_assert( new_partition != NULL );  // Bug: Not initialised by constructor calling set_data()
 
 	// combo_type
-	if ( type )
+	if (combo_type_changed)
 	{
 		if (combo_type.get_active_row_number() == TYPE_EXTENDED      &&
 		    combo_filesystem.items().size()    <  FILESYSTEMS.size()   )
@@ -342,14 +344,14 @@ void Dialog_Partition_New::combobox_changed(bool type)
 		else if (combo_type.get_active_row_number() != TYPE_EXTENDED      &&
 		         combo_filesystem.items().size()    == FILESYSTEMS.size()   )
 		{
+			combo_filesystem.set_active(default_fs);
 			combo_filesystem.items().erase(combo_filesystem.items().back());
 			combo_filesystem.set_sensitive(true);
-			combo_filesystem.set_active(first_creatable_fs);
 		}
 	}
-	
+
 	// combo_filesystem and combo_alignment
-	if ( ! type )
+	if (! combo_type_changed)
 	{
 		fs = FILESYSTEMS[combo_filesystem.get_active_row_number()];
 		fs_limits = GParted_Core::get_filesystem_limits(fs.fstype, *new_partition);
@@ -405,17 +407,29 @@ void Dialog_Partition_New::build_filesystems_combo(bool only_unformatted)
 	g_assert( new_partition != NULL );  // Bug: Not initialised by constructor calling set_data()
 	combo_filesystem.items().clear();
 
-	bool set_first=false;
-	//fill the file system menu with the file systems (except for extended) 
+	// Fill the file system combobox
 	for ( unsigned int t = 0 ; t < FILESYSTEMS .size( ) ; t++ ) 
 	{
-		//skip extended
+		// Skip extended which is only added by combobox_changed() while partition
+		// type = extended.
 		if (FILESYSTEMS[t].fstype == FS_EXTENDED)
 			continue ;
+
 		combo_filesystem.items().push_back(Utils::get_filesystem_string(FILESYSTEMS[t].fstype));
-		combo_filesystem.items().back().set_sensitive(
-			! only_unformatted && FILESYSTEMS[ t ] .create &&
-			new_partition->get_byte_length() >= get_filesystem_min_limit(FILESYSTEMS[t].fstype));
+
+		if (FILESYSTEMS[t].fstype == FS_UNFORMATTED)
+		{
+			// Unformatted is always available
+			combo_filesystem.items().back().set_sensitive(true);
+		}
+		else
+		{
+			combo_filesystem.items().back().set_sensitive(
+				! only_unformatted                                                                  &&
+				FILESYSTEMS[t].create                                                               &&
+				new_partition->get_byte_length() >= get_filesystem_min_limit(FILESYSTEMS[t].fstype)   );
+		}
+
 		//use ext4/3/2 as first/second/third choice default file system
 		//(Depends on ordering in FILESYSTEMS for preference)
 		if ((FILESYSTEMS[t].fstype == FS_EXT2 ||
@@ -423,21 +437,18 @@ void Dialog_Partition_New::build_filesystems_combo(bool only_unformatted)
 		     FILESYSTEMS[t].fstype == FS_EXT4   )      &&
 		    combo_filesystem.items().back().sensitive()  )
 		{
-			first_creatable_fs = combo_filesystem.items().size() - 1;
-			set_first=true;
+			default_fs = combo_filesystem.items().size() - 1;
 		}
 	}
-	
-	//unformatted is always available
-	combo_filesystem.items().back().set_sensitive(true);
 
-	if(!set_first)
+	if (default_fs < 0)
 	{
-		//find and set first enabled file system as last choice default
+		// Find and set first enabled file system as last choice default.  Note
+		// that unformatted will always be available.
 		for (unsigned int t = 0; t < combo_filesystem.items().size(); t++)
 			if (combo_filesystem.items()[t].sensitive())
 			{
-				first_creatable_fs = t ;
+				default_fs = t;
 				break ;
 			}
 	}
