@@ -15,6 +15,7 @@
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "Device.h"
 #include "Dialog_Partition_Resize_Move.h"
 #include "FileSystem.h"
 #include "GParted_Core.h"
@@ -25,9 +26,11 @@
 namespace GParted
 {
 
-Dialog_Partition_Resize_Move::Dialog_Partition_Resize_Move( const FS & fs, const FS_Limits & fs_limits,
-                                                            const Partition & selected_partition,
-                                                            const PartitionVector & partitions )
+Dialog_Partition_Resize_Move::Dialog_Partition_Resize_Move(const Device& device, const FS & fs,
+                                                           const FS_Limits & fs_limits,
+                                                           const Partition & selected_partition,
+                                                           const PartitionVector & partitions)
+ : Dialog_Base_Partition(device)
 {
 	this ->fs = fs ;
 	this->fs_limits = fs_limits;
@@ -59,7 +62,7 @@ void Dialog_Partition_Resize_Move::set_data( const Partition & selected_partitio
 	}
 
 	// Set partition color
-	Gdk::RGBA partition_color(Utils::get_color(selected_partition.filesystem));
+	Gdk::RGBA partition_color(Utils::get_color(selected_partition.fstype));
 	frame_resizer_base->set_rgb_partition_color( partition_color );
 
 	//store the original values
@@ -79,9 +82,9 @@ void Dialog_Partition_Resize_Move::Resize_Move_Normal( const PartitionVector & p
 
 	// Don't permit shrinking an existing file system (other than linux-swap) when the
 	// usage is unknown as that sets the minimum resize.
-	if ( ! new_partition->sector_usage_known()      &&
-	     new_partition->status     != STAT_NEW      &&
-	     new_partition->filesystem != FS_LINUX_SWAP    )
+	if (! new_partition->sector_usage_known()  &&
+	    new_partition->status != STAT_NEW      &&
+	    new_partition->fstype != FS_LINUX_SWAP   )
 		fs.shrink = FS::NONE;
 
 	//Disable resizing as it's currently disallowed for the file system in this partition.
