@@ -19,10 +19,13 @@
 #include "lvm2_pv.h"
 #include "Partition.h"
 
+#include <glibmm/shell.h>
+
+
 namespace GParted
 {
 
-const Glib::ustring lvm2_pv::get_custom_text( CUSTOM_TEXT ttype, int index ) const
+const Glib::ustring & lvm2_pv::get_custom_text( CUSTOM_TEXT ttype, int index ) const
 {
 	/*TO TRANSLATORS: these labels will be used in the partition menu */
 	static const Glib::ustring activate_text = _( "Ac_tivate" ) ;
@@ -31,17 +34,18 @@ const Glib::ustring lvm2_pv::get_custom_text( CUSTOM_TEXT ttype, int index ) con
 	static const Glib::ustring resize_warning =
 		_( "The LVM2 Physical Volume can not currently be resized because it is a member of an exported "
 		   "Volume Group." ) ;
+	static const Glib::ustring empty_text;
 
 	switch ( ttype )
 	{
 		case CTEXT_ACTIVATE_FILESYSTEM:
-			return index == 0 ? activate_text : "" ;
+			return index == 0 ? activate_text : empty_text;
 		case CTEXT_DEACTIVATE_FILESYSTEM:
-			return index == 0 ? deactivate_text : "" ;
+			return index == 0 ? deactivate_text : empty_text;
 		case CTEXT_RESIZE_DISALLOWED_WARNING:
-			return index == 0 ? resize_warning : "" ;
+			return index == 0 ? resize_warning : empty_text;
 		default:
-			return "" ;
+			return empty_text;
 	}
 }
 
@@ -102,7 +106,7 @@ bool lvm2_pv::resize( const Partition & partition_new, OperationDetail & operati
 {
 	Glib::ustring size = "" ;
 	if ( ! fill_partition )
-		size = " --setphysicalvolumesize " +
+		size = " --yes --setphysicalvolumesize " +
 			Utils::num_to_str( floor( Utils::sector_to_unit(
 				partition_new .get_sector_length(), partition_new .sector_size, UNIT_KIB ) ) ) + "K " ;
 	return ! execute_command( "lvm pvresize -v " + size + Glib::shell_quote( partition_new.get_path() ),
